.. Python JSONSchema Objects documentation master file, created by
   sphinx-quickstart on Tue Mar 15 12:48:39 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Python JSONSchema Objects's documentation!
=====================================================

python-jsonschema-objects provides an *automatic* class-based
binding to JSON schemas for use in python.

.. toctree::
   :includehidden:

   Introduction

   apidoc

